function fbr = mrtrix2fiber(xdim,ydim,zdim)


%mrtrix2bvfiber.m
%Convert MRTrix fiber file to BrainVoyager fiber file
%MRtrix software and read_mrtrix_tracks.m by J-D Tournier, Brain Research Institute, Melbourne,
%Australia, http://www.brain.org.au/software/
%usage: 
%
% >> fbr = mrtrix2bvfiber(xdim,ydim,zdim);
% where xdim: anterior-posterior dimension of VMR(!)
% ydim: inferior-superior dimension
% zdim: left-right dimension
%
% or alternatively 
% >> fbr = mrtrix2fiber;
%
%requires BVQXtools package from
%http://support.brainvoyager.com/available-tools/52-matlab-tools-bvxqtools.html

%Pim Pullens -- Brain Innovation BV -- Maastricht NL
%July 21, 2010
%send remarks and questions to pullens AT brainvoyager DOT com

MRtrixFile = uigetfile('*.tck','Please select MRtrix fiber file...');

%read MRtrix tracts
tracts = read_mrtrix_tracks(MRtrixFile);
disp('successfully read MRtrix tracts'); 

%setup BV fiber file
fbr = BVQXfile('new:fbr');

%ask vmr dims
if nargin~=3,
disp('I need to set dimensions from BrainVoyager. These are the same as your VMR dimensions');
xdim = input('please set BV x-dimension (Anterior-Posterior) : ');
ydim = input('please set BV y-dimension (Inferior-Superior) : ');
zdim = input('please set BV z-dimension (Left-Right) : ');
end
% xdim=256;
% ydim=256;
% zdim=192;

%set origin
fbr.FibersOriginX = xdim/2;
fbr.FibersOriginY = ydim/2;
fbr.FibersOriginZ = zdim/2;

disp(['fiber origin set to [x y z]: ', num2str(xdim/2),' ', ...
    num2str(ydim/2),' ', num2str(zdim/2)]); 
%determine nr of MRtrix fibers
fbr.Group(1).NrOfFibers = str2num(tracts.count);
nrfibers = str2num(tracts.count);
display(['number of MRtrix fibers: ',num2str(tracts.count)]);

%set name
fbr.Group(1).Name = '"Fibers from MRtrix"';
%copy fibers to BV fiber structure
tcolor = fbr.Group.Color;
disp('copying fibers');

for i = 1:nrfibers,
    tmpfiber = struct('NrOfPoints',[],'FiberPoints',[]);
    q = cell2mat(tracts.data(i));
    tmpfiber.NrOfPoints = length(q);
    tmpfiber.FiberPoints = zeros(tmpfiber.NrOfPoints,6);
    r = [xdim/2+q(:,2) ydim/2-q(:,3) zdim/2-q(:,1)];
    %r = [xdim-q(:,2) ydim-q(:,3) zdim-q(:,1)]; 
    tmpfiber.FiberPoints(:,1:3) = r;
    colors = repmat(tcolor,tmpfiber.NrOfPoints,1);
    tmpfiber.FiberPoints(:,4:6) = colors;
    fbr.Group(1).Fiber(i) = tmpfiber;
    clear tmpfiber q r;
end

fbr.SaveAs;
disp('Done.');